==> c8y_client-0.0.1.tar.gz: lib/src/core/implementations/paged_resource_collention.dart <==
import 'package:c8y_client/src/core/model/paged_collection_resource.dart';
import 'package:c8y_client/src/core/util/url_processor.dart';
import 'package:c8y_client/src/core/model/base_collection.dart';
import 'package:c8y_client/src/rest/representation/cumulocity_media_type.dart';
import 'package:c8y_client/src/sdk/client/rest_connector.dart';
import 'package:c8y_client/src/sdk/client/sdk_exception.dart';

abstract class PagedResourceCollectionImpl<
    T,
    C extends BaseCollectionRepresentation<T>,
    I extends C> implements PagedCollectionResource<T, I> {
  final RestConnector _restConnector;
  final String _path;
  int _pageSize;
  var urlHelper = UrlProcessor();

  I wrap(C collection);

  dynamic parser(Map<String, Object> json);

  PagedResourceCollectionImpl(this._restConnector, this._path, this._pageSize);

  @override
  String PAGE_NUMBER_KEY;

  @override
  String PAGE_SIZE_KEY;

  @override
  Future<I> get(Map<String, Object> queryParams) async {
    queryParams.putIfAbsent('pageSize', () => _pageSize.toString());
    return wrap((await _restConnector.get(
            urlHelper.addQueryParam(_path, queryParams), MediaType(), parser))
        as BaseCollectionRepresentation);
  }

  Future<I> getWithPageSize(int pageSize) async {
    try {
      return get({'pageSize': pageSize});
    } catch (error) {
      print(error);
    }
  }

  Future<I> getWithFragmentTypeAndName(int pageSize) async {
    return get({'pageSize': pageSize});
  }

  @override
  Future<I> getNextPage(BaseCollectionRepresentation collectionRepresentation) {
    if (collectionRepresentation == null) {
      throw SDKException('Unable to determin the Resource URL');
    } else {
      return collectionRepresentation.next == null
          ? null
          : getCollection(collectionRepresentation.next);
    }
  }

  Future<I> getCollection(url) async {
    return wrap((await _restConnector.get(url, MediaType(), parser))
        as BaseCollectionRepresentation);
  }

  @override
  Future<I> getPage(
      BaseCollectionRepresentation collectionRepresentation, int pageNumber) {
    // TODO: implement getPage
    return null;
  }

  @override
  Future<I> getPreviousPage(BaseCollectionRepresentation var1) {
    // TODO: implement getPreviousPage
    return null;
  }

  CumulocityMediaType MediaType();
}

==> c8y_client-0.0.3.tar.gz: lib/src/core/implementations/paged_resource_collention.dart <==
import 'package:c8y_client/src/core/model/paged_collection_resource.dart';
import 'package:c8y_client/src/core/util/url_processor.dart';
import 'package:c8y_client/src/core/model/base_collection.dart';
import 'package:c8y_client/src/core/model/cumulocity_media_type.dart';
import 'package:c8y_client/src/sdk/client/rest_connector.dart';
import 'package:c8y_client/src/sdk/client/sdk_exception.dart';

abstract class PagedResourceCollectionImpl<
    T,
    C extends BaseCollectionRepresentation<T>,
    I extends C> implements PagedCollectionResource<T, I> {
  final RestConnector _restConnector;
  final String _path;
  final int _pageSize;
  var urlHelper = UrlProcessor();

  I wrap(C collection);

  CumulocityMediaType mediaType();

  dynamic parser(Map<String, Object> json);

  PagedResourceCollectionImpl(this._restConnector, this._path, this._pageSize);

  @override
  String PAGE_NUMBER_KEY;

  @override
  String PAGE_SIZE_KEY;

  @override
  Future<I> get(Map<String, Object> queryParams) async {
    queryParams.putIfAbsent('pageSize', () => _pageSize.toString());
    return wrap((await _restConnector.get(
            urlHelper.addQueryParam(_path, queryParams), mediaType(), parser))
        as BaseCollectionRepresentation);
  }

  Future<I> getWithPageSize(int pageSize) async {
    return await get({'pageSize': pageSize});
  }

  @override
  Future<I> getNextPage(BaseCollectionRepresentation collectionRepresentation) {
    if (collectionRepresentation == null) {
      throw SDKException('Unable to determin the Resource URL');
    } else {
      return collectionRepresentation.next == null
          ? null
          : getCollection(collectionRepresentation.next);
    }
  }

  Future<I> getCollection(url) async {
    return wrap((await _restConnector.get(url, mediaType(), parser))
        as BaseCollectionRepresentation);
  }

  @override
  Future<I> getPage(
      BaseCollectionRepresentation collectionRepresentation, int pageNumber) {
    // TODO: implement getPage
    return null;
  }

  @override
  Future<I> getPreviousPage(BaseCollectionRepresentation var1) {
    // TODO: implement getPreviousPage
    return null;
  }
}
